@@ -5,8 +5,8 @@
 ;; Author: Feng Shu <tumashu@163.com>
 ;; Maintainer: Feng Shu <tumashu@163.com>
 ;; URL: https://github.com/tumashu/posframe
-;; Package-Version: 20260225.112
-;; Package-Revision: 41cc4def6190
+;; Package-Version: 20260302.251
+;; Package-Revision: 3a80911b2f45
 ;; Keywords: convenience, tooltip
 ;; Package-Requires: ((emacs "26.1"))
 
@@ -137,7 +137,7 @@ effect.")
        (not emacs-basic-display)
        (or (display-graphic-p)
            (featurep 'tty-child-frames))
-       (eq (frame-parameter (selected-frame) 'minibuffer) 't)))
+       (not (eq (frame-parameter (selected-frame) 'minibuffer) 'only))))
 
 ;;;###autoload
 (cl-defun posframe-show (buffer-or-name
